@@ -307,11 +307,16 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "MOVE_DOUBLE",
   "MOVE_OBJECT",
   "MOVE_UNDEF",
-  "MOVE_VALUES",
   "ENTER_SCOPE",
   "PUSH_MORTAL",
   "LEAVE_SCOPE",
-  "PUSH_ARG",
+  "PUSH_ARG_BYTE",
+  "PUSH_ARG_SHORT",
+  "PUSH_ARG_INT",
+  "PUSH_ARG_LONG",
+  "PUSH_ARG_FLOAT",
+  "PUSH_ARG_DOUBLE",
+  "PUSH_ARG_OBJECT",
   "PUSH_ARG_UNDEF",
   "CAST",
   "STRING_EQ",
