@@ -184,7 +184,7 @@ int32_t SPVM_RUNTIME_API_check_cast(SPVM_ENV* env, int32_t cast_basic_type_id, i
   SPVM_RUNTIME* runtime = SPVM_RUNTIME_API_get_runtime();
   SPVM_COMPILER* compiler = runtime->compiler;
   
-  return SPVM_OP_CHECKER_can_assign(compiler, cast_basic_type_id, cast_type_dimension, object->basic_type_id, object->dimension);
+  return SPVM_OP_CHECKER_check_cast(compiler, cast_basic_type_id, cast_type_dimension, object->basic_type_id, object->dimension);
 }
 
 SPVM_OBJECT* SPVM_RUNTIME_API_create_exception_stack_trace(SPVM_ENV* env, SPVM_OBJECT* exception, const char* package_name, const char* sub_name, const char* file, int32_t line) {
@@ -1014,7 +1014,7 @@ void SPVM_RUNTIME_API_dec_ref_count(SPVM_ENV* env, SPVM_OBJECT* object) {
       {
         int32_t index;
         for (index = 0; index < length; index++) {
-          SPVM_OBJECT** object_field_address = &((*(SPVM_VALUE_object**)&(*(void**)object))[index]);
+          SPVM_OBJECT** object_field_address = (SPVM_OBJECT**)&((*(SPVM_VALUE_object**)&(*(void**)object))[index]);
           if (*object_field_address != NULL) {
             SPVM_RUNTIME_API_dec_ref_count(env, *object_field_address);
           }
@@ -1048,7 +1048,7 @@ void SPVM_RUNTIME_API_dec_ref_count(SPVM_ENV* env, SPVM_OBJECT* object) {
         for (index = 0; index < package->object_field_indexes->length; index++) {
           int32_t object_field_index = (intptr_t)SPVM_LIST_fetch(package->object_field_indexes, index);
           SPVM_VALUE* fields = *(SPVM_VALUE**)&(*(void**)object);
-          SPVM_OBJECT** object_field_address = (SPVM_VALUE_object*)&fields[object_field_index];
+          SPVM_OBJECT** object_field_address = (SPVM_OBJECT**)&fields[object_field_index];
           if (*object_field_address != NULL) {
             // If object is weak, unweaken
             if (SPVM_RUNTIME_API_isweak(env, *object_field_address)) {
@@ -1277,7 +1277,7 @@ int32_t SPVM_RUNTIME_API_weaken_object_field(SPVM_ENV* env, SPVM_OBJECT* object,
   }
 
   SPVM_VALUE* fields = *(SPVM_VALUE**)&(*(void**)object);
-  SPVM_OBJECT** object_field_address = (SPVM_VALUE_object*)&fields[field_index];
+  SPVM_OBJECT** object_field_address = (SPVM_OBJECT**)&fields[field_index];
   
   // Weaken object field
   if (*object_field_address != NULL) {
